import React, { useEffect } from 'react';
import { observer } from "mobx-react";
import { Navigate } from "react-router-dom";
import { useInjection } from "inversify-react";
import { AuthStore } from "../stores/AuthStore";

type TokenCheckProps = {
    children: React.ReactNode | React.ReactNode[];
    required?: boolean;
}

const TokenCheck = observer(({ children, required = true }: TokenCheckProps) => {
    const authStore = useInjection(AuthStore);

    useEffect(() => {
        console.log('token changed', authStore.token);
    }, [authStore.token]);

    if (required && !authStore.token)
        return <Navigate to='/signin' state='not_signed_in' />;
    else if (!required && authStore.token)
        return <Navigate to='/' />;

    return (
        <>
            {children}
        </>
    )
});

export default TokenCheck;
